@@ -31,61 +31,59 @@
 #endif
 
 typedef enum {
-  MODE_CALENDAR,
-  MODE_ENTRY,
-  MODE_ERROR,
-  MODE_FILE,
-  MODE_LIST,
-  MODE_PROGRESS,
-  MODE_QUESTION,
-  MODE_TEXTINFO,
-  MODE_WARNING,
-  MODE_SCALE,
-  MODE_INFO,
+	MODE_CALENDAR,
+	MODE_ENTRY,
+	MODE_ERROR,
+	MODE_FILE,
+	MODE_LIST,
+	MODE_PROGRESS,
+	MODE_QUESTION,
+	MODE_TEXTINFO,
+	MODE_WARNING,
+	MODE_SCALE,
+	MODE_INFO,
 #ifdef HAVE_LIBNOTIFY
-  MODE_NOTIFICATION,
+	MODE_NOTIFICATION,
 #endif
-  MODE_COLOR,
-  MODE_PASSWORD,
-  MODE_FORMS,
-  MODE_ABOUT,
-  MODE_VERSION,
-  MODE_LAST
+	MODE_COLOR,
+	MODE_PASSWORD,
+	MODE_FORMS,
+	MODE_ABOUT,
+	MODE_VERSION,
+	MODE_LAST
 } ZenityDialogMode;
 
 typedef enum {
-  ERROR_SYNTAX,
-  ERROR_SUPPORT,
-  ERROR_DIALOG,
-  ERROR_LAST
+	ERROR_SYNTAX,
+	ERROR_SUPPORT,
+	ERROR_DIALOG,
+	ERROR_LAST
 } ZenityError;
 
 typedef struct {
-  ZenityDialogMode mode;
-  ZenityData      *data;
+	ZenityDialogMode mode;
+	ZenityData *data;
 
-  ZenityCalendarData     *calendar_data;
-  ZenityMsgData          *msg_data;
-  ZenityScaleData        *scale_data;
-  ZenityFileData         *file_data;
-  ZenityEntryData        *entry_data;
-  ZenityProgressData     *progress_data;
-  ZenityTextData         *text_data;
-  ZenityTreeData         *tree_data;
+	ZenityCalendarData *calendar_data;
+	ZenityMsgData *msg_data;
+	ZenityScaleData *scale_data;
+	ZenityFileData *file_data;
+	ZenityEntryData *entry_data;
+	ZenityProgressData *progress_data;
+	ZenityTextData *text_data;
+	ZenityTreeData *tree_data;
 #ifdef HAVE_LIBNOTIFY
-  ZenityNotificationData *notification_data;
+	ZenityNotificationData *notification_data;
 #endif
-  ZenityColorData        *color_data;
-  ZenityPasswordData     *password_data;
-  ZenityFormsData        *forms_data;
+	ZenityColorData *color_data;
+	ZenityPasswordData *password_data;
+	ZenityFormsData *forms_data;
 } ZenityParsingOptions;
 
-void			zenity_option_error (gchar	*string,
-					     ZenityError error);
+void zenity_option_error (gchar *string, ZenityError error);
 
-ZenityParsingOptions * 	zenity_option_parse (gint	 argc,
-					     gchar     **argv); 
+ZenityParsingOptions *zenity_option_parse (gint argc, gchar **argv);
 
-void 			zenity_option_free (void);
+void zenity_option_free (void);
 
 #endif /* OPTION_H */
